Stan Math Library: stan/math/prim/mat/fun/append_col.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
append_col.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/scal/meta/return_type.hpp>`
`#include <stan/math/prim/scal/err/check_size_match.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T1 , typename T2 , int R1, int C1, int R2, int C2>
Eigen::Matrix< typename return_type< T1, T2 >::type, Eigen::Dynamic, Eigen::Dynamic > | stan::math::append_col (const Eigen::Matrix< T1, R1, C1 > &A, const Eigen::Matrix< T2, R2, C2 > &B)
| Return the result of appending the second argument matrix after the first argument matrix, that is, putting them side by side, with the first matrix followed by the second matrix. More...
template<typename T1 , typename T2 , int C1, int C2>
Eigen::Matrix< typename return_type< T1, T2 >::type, 1, Eigen::Dynamic > | stan::math::append_col (const Eigen::Matrix< T1, 1, C1 > &A, const Eigen::Matrix< T2, 1, C2 > &B)
| Return the result of concatenaing the first row vector followed by the second row vector side by side, with the result being a row vector. More...
template<typename T , int R1, int C1, int R2, int C2>
Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > | stan::math::append_col (const Eigen::Matrix< T, R1, C1 > &A, const Eigen::Matrix< T, R2, C2 > &B)
| Return the result of appending the second argument matrix after the first argument matrix, that is, putting them side by side, with the first matrix followed by the second matrix. More...
template<typename T , int C1, int C2>
Eigen::Matrix< T, 1, Eigen::Dynamic > | stan::math::append_col (const Eigen::Matrix< T, 1, C1 > &A, const Eigen::Matrix< T, 1, C2 > &B)
| Return the result of concatenaing the first row vector followed by the second row vector side by side, with the result being a row vector. More...
template<typename T1 , typename T2 , int R, int C>
Eigen::Matrix< typename return_type< T1, T2 >::type, 1, Eigen::Dynamic > | stan::math::append_col (const T1 &A, const Eigen::Matrix< T2, R, C > &B)
| Return the result of stacking an scalar on top of the a row vector, with the result being a row vector. More...
template<typename T1 , typename T2 , int R, int C>
Eigen::Matrix< typename return_type< T1, T2 >::type, 1, Eigen::Dynamic > | stan::math::append_col (const Eigen::Matrix< T1, R, C > &A, const T2 &B)
| Return the result of stacking a row vector on top of the an scalar, with the result being a row vector. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.